@@ -67,7 +67,6 @@ pub struct Precious<'a> {
     config_file: PathBuf,
     chars: chars::Chars,
     quiet: bool,
-    basepaths: Option<basepaths::BasePaths>,
     thread_pool: ThreadPool,
 }
 
@@ -204,6 +203,12 @@ pub fn init_logger(matches: &ArgMatches) -> Result<(), log::SetLoggerError> {
 
 impl<'a> Precious<'a> {
     pub fn new(matches: &'a ArgMatches) -> Result<Precious<'a>> {
+        if log::log_enabled!(log::Level::Debug) {
+            if let Some(path) = env::var_os("PATH") {
+                debug!("PATH = {}", path.to_string_lossy());
+            }
+        }
+
         let c = if matches.is_present("ascii") {
             chars::BORING_CHARS
         } else {
@@ -223,7 +228,6 @@ impl<'a> Precious<'a> {
             cwd,
             chars: c,
             quiet: matches.is_present("quiet"),
-            basepaths: None,
             thread_pool: ThreadPoolBuilder::new()
                 .num_threads(Self::jobs(matches)?)
                 .build()?,
@@ -310,6 +314,7 @@ impl<'a> Precious<'a> {
     pub fn run(&mut self) -> i8 {
         match self.run_subcommand() {
             Ok(e) => {
+                debug!("{:?}", e);
                 if let Some(err) = e.error {
                     print!("{}", err);
                 }
@@ -720,6 +725,8 @@ mod tests {
     // Anything that does pushd must be run serially or else chaos ensues.
     use serial_test::serial;
     use spectral::prelude::*;
+    use std::{path::PathBuf, str::FromStr};
+    use which::which;
 
     const SIMPLE_CONFIG: &str = r#"
 [commands.rustfmt]
@@ -788,7 +795,7 @@ lint_failure_exit_codes = [1]
 
     #[test]
     #[serial]
-    fn test_set_root_prefers_config_file() -> Result<()> {
+    fn set_root_prefers_config_file() -> Result<()> {
         let helper = testhelper::TestHelper::new()?.with_git_repo()?;
 
         let mut src_dir = helper.root();
@@ -809,7 +816,7 @@ lint_failure_exit_codes = [1]
 
     #[test]
     #[serial]
-    fn test_basepaths_uses_cwd() -> Result<()> {
+    fn basepaths_uses_cwd() -> Result<()> {
         let helper = testhelper::TestHelper::new()?
             .with_config_file(SIMPLE_CONFIG)?
             .with_git_repo()?;
@@ -838,7 +845,7 @@ lint_failure_exit_codes = [1]
 
     #[test]
     #[serial]
-    fn test_tidy_succeeds() -> Result<()> {
+    fn tidy_succeeds() -> Result<()> {
         let config = r#"
 [commands.true]
 type    = "tidy"
@@ -862,7 +869,7 @@ ok_exit_codes = [0]
 
     #[test]
     #[serial]
-    fn test_tidy_fails() -> Result<()> {
+    fn tidy_fails() -> Result<()> {
         let config = r#"
 [commands.false]
 type    = "tidy"
@@ -886,7 +893,7 @@ ok_exit_codes = [0]
 
     #[test]
     #[serial]
-    fn test_lint_succeeds() -> Result<()> {
+    fn lint_succeeds() -> Result<()> {
         let config = r#"
 [commands.true]
 type    = "lint"
@@ -911,7 +918,7 @@ lint_failure_exit_codes = [1]
 
     #[test]
     #[serial]
-    fn test_lint_fails() -> Result<()> {
+    fn lint_fails() -> Result<()> {
         let config = r#"
 [commands.false]
 type    = "lint"
@@ -935,7 +942,60 @@ lint_failure_exit_codes = [1]
     }
 
     #[test]
-    fn test_format_duration() {
+    #[serial]
+    // This fails in CI on Windows with a confusing error - "Cannot complete
+    // in-place edit of test.replace: Work file is missing - did you change
+    // directory?" I don't know what this means, and it's not really important
+    // to run this test on every OS.
+    #[cfg(not(target_os = "windows"))]
+    fn command_order_is_preserved_when_running() -> Result<()> {
+        if which("perl").is_err() {
+            println!("Skipping test since perl is not in path");
+            return Ok(());
+        }
+
+        let config = r#"
+[commands.perl-replace-a-with-b]
+type    = "tidy"
+include = "test.replace"
+cmd     = ["perl", "-pi", "-e", "s/a/b/i"]
+ok_exit_codes = [0]
+
+[commands.perl-replace-a-with-c]
+type    = "tidy"
+include = "test.replace"
+cmd     = ["perl", "-pi", "-e", "s/a/c/i"]
+ok_exit_codes = [0]
+lint_failure_exit_codes = [1]
+
+[commands.perl-replace-a-with-d]
+type    = "tidy"
+include = "test.replace"
+cmd     = ["perl", "-pi", "-e", "s/a/d/i"]
+ok_exit_codes = [0]
+lint_failure_exit_codes = [1]
+"#;
+        let helper = testhelper::TestHelper::new()?.with_config_file(config)?;
+        let test_replace = PathBuf::from_str("test.replace")?;
+        helper.write_file(test_replace.as_ref(), "The letter A")?;
+        let _pushd = helper.pushd_to_root()?;
+
+        let app = app();
+        let matches = app.get_matches_from_safe(&["precious", "--quiet", "tidy", "-a"])?;
+
+        let mut p = Precious::new(&matches)?;
+        let status = p.run();
+
+        assert_that(&status).is_equal_to(0);
+
+        let content = helper.read_file(test_replace.as_ref())?;
+        assert_that(&content).is_equal_to("The letter b".to_string());
+
+        Ok(())
+    }
+
+    #[test]
+    fn format_duration_output() {
         let mut tests: HashMap<Duration, &'static str> = HashMap::new();
         tests.insert(Duration::new(0, 24), "24ns");
         tests.insert(Duration::new(0, 124), "124ns");
